@@ -17,14 +17,17 @@
 """handles command line and config file option parsing for the gbp commands"""
 
 from optparse import OptionParser, OptionGroup, Option, OptionValueError
-from ConfigParser import SafeConfigParser, NoSectionError
+from six.moves import configparser
 from copy import copy
 import os.path
+
 try:
     from gbp.version import gbp_version
 except ImportError:
     gbp_version = "[Unknown version]"
 import gbp.tristate
+import gbp.log
+from gbp.git import GitRepositoryError, GitRepository
 
 no_upstream_branch_msg = """
 Repository does not have branch '%s' for upstream sources. If there is none see
@@ -119,7 +122,7 @@ class GbpOptionParser(OptionParser):
                  'tarball-dir'     : '',
                  'ignore-new'      : 'False',
                  'ignore-branch'   : 'False',
-                 'meta'            : 'False',
+                 'meta'            : 'True',
                  'meta-closes'     : 'Closes|LP',
                  'full'            : 'False',
                  'id-length'       : '0',
@@ -157,6 +160,7 @@ class GbpOptionParser(OptionParser):
                  'purge': 'True',
                  'drop': 'False',
                  'commit': 'False',
+                 'upstream-vcs-tag': '',
              }
     help = {
              'debian-branch':
@@ -307,28 +311,32 @@ class GbpOptionParser(OptionParser):
 
     def_config_files = [ '/etc/git-buildpackage/gbp.conf',
                          '~/.gbp.conf',
-                         '.gbp.conf',
-                         'debian/gbp.conf',
-                         '.git/gbp.conf' ]
+                         '%(top_dir)s/.gbp.conf',
+                         '%(top_dir)s/debian/gbp.conf',
+                         '%(git_dir)s/gbp.conf' ]
 
     @classmethod
-    def get_config_files(klass):
+    def get_config_files(klass, no_local=False):
         """
         Get list of config files from the I{GBP_CONF_FILES} environment
         variable.
 
+        @param no_local: don't return the per-repo configuration files
+        @type no_local: C{bool}
         @return: list of config files we need to parse
         @rtype: C{list}
 
         >>> conf_backup = os.getenv('GBP_CONF_FILES')
         >>> if conf_backup is not None: del os.environ['GBP_CONF_FILES']
+        >>> homedir = os.path.expanduser("~")
         >>> files = GbpOptionParser.get_config_files()
-
-        # Remove the ~-expanded one
-        >>> del files[1]
-        >>> files
-        ['/etc/git-buildpackage/gbp.conf', '.gbp.conf', 'debian/gbp.conf', '.git/gbp.conf']
-
+        >>> files_mangled = [file.replace(homedir, 'HOME') for file in files]
+        >>> files_mangled
+        ['/etc/git-buildpackage/gbp.conf', 'HOME/.gbp.conf', '%(top_dir)s/.gbp.conf', '%(top_dir)s/debian/gbp.conf', '%(git_dir)s/gbp.conf']
+        >>> files = GbpOptionParser.get_config_files(no_local=True)
+        >>> files_mangled = [file.replace(homedir, 'HOME') for file in files]
+        >>> files_mangled
+        ['/etc/git-buildpackage/gbp.conf', 'HOME/.gbp.conf']
         >>> os.environ['GBP_CONF_FILES'] = 'test1:test2'
         >>> GbpOptionParser.get_config_files()
         ['test1', 'test2']
@@ -337,35 +345,66 @@ class GbpOptionParser(OptionParser):
         """
         envvar = os.environ.get('GBP_CONF_FILES')
         files = envvar.split(':') if envvar else klass.def_config_files
-        return [ os.path.expanduser(f) for f in files ]
+        files = [os.path.expanduser(fname) for fname in files]
+        if no_local:
+            files = [fname for fname in files if fname.startswith('/')]
+        return files
+
+    def _read_config_file(self, parser, repo, filename):
+        """Read config file"""
+        str_fields = {}
+        if repo:
+            str_fields['git_dir'] = repo.git_dir
+            if not repo.bare:
+                str_fields['top_dir'] = repo.path
+        try:
+            filename = filename % str_fields
+        except KeyError:
+            # Skip if filename wasn't expanded, i.e. we're not in git repo
+            return
+        parser.read(filename)
+
+    def _warn_old_config_section(self, oldcmd, cmd):
+        if not os.getenv("GBP_DISABLE_SECTION_DEPRECTATION"):
+            gbp.log.warn("Old style config section [%s] found "
+                         "please rename to [%s]" % (oldcmd, cmd))
 
     def parse_config_files(self):
         """
         Parse the possible config files and set appropriate values
         default values
         """
-        parser = SafeConfigParser()
+        parser = configparser.SafeConfigParser()
         # Fill in the built in values
         self.config = dict(self.__class__.defaults)
         # Update with the values from the defaults section. This is needed
         # in case the config file doesn't have a [<command>] section at all
-        parser.read(self.config_files)
+        config_files = self.get_config_files()
+        try:
+            repo = GitRepository(".")
+        except GitRepositoryError:
+            repo = None
+        # Read all config files
+        for filename in config_files:
+            self._read_config_file(parser, repo, filename)
         self.config.update(dict(parser.defaults()))
 
         # Make sure we read any legacy sections prior to the real subcommands
         # section i.e. read [gbp-pull] prior to [pull]
         if (self.command.startswith('gbp-') or
             self.command.startswith('git-')):
+            cmd = self.command[4:]
             oldcmd = self.command
             if parser.has_section(oldcmd):
                 self.config.update(dict(parser.items(oldcmd, raw=True)))
-            cmd = self.command[4:]
+                self._warn_old_config_section(oldcmd, cmd)
         else:
+            cmd = self.command
             for prefix in ['gbp', 'git']:
                 oldcmd = '%s-%s' % (prefix, self.command)
                 if parser.has_section(oldcmd):
                     self.config.update(dict(parser.items(oldcmd, raw=True)))
-            cmd = self.command
+                    self._warn_old_config_section(oldcmd, cmd)
 
         # Update with command specific settings
         if parser.has_section(cmd):
@@ -377,8 +416,8 @@ class GbpOptionParser(OptionParser):
             if parser.has_section(section):
                 self.config.update(dict(parser._sections[section].items()))
             else:
-                raise NoSectionError("Mandatory section [%s] does not exist."
-                                     % section)
+                raise configparser.NoSectionError(
+                        "Mandatory section [%s] does not exist." % section)
 
         # filter can be either a list or a string, always build a list:
         if self.config['filter']:
@@ -405,7 +444,6 @@ class GbpOptionParser(OptionParser):
         self.sections = sections
         self.prefix = prefix
         self.config = {}
-        self.config_files = self.get_config_files()
         self.parse_config_files()
         self.valid_options = []
 
@@ -541,6 +579,7 @@ class GbpOptionParserRpm(GbpOptionParser):
             'packaging-branch'          : 'master',
             'packaging-dir'             : '',
             'packaging-tag'             : 'packaging/%(version)s',
+            'spec-file'                 : '',
                     })
 
     help = dict(GbpOptionParser.help)
@@ -560,6 +599,9 @@ class GbpOptionParserRpm(GbpOptionParser):
             'packaging-tag':
                 "Format string for packaging tags, RPM counterpart of the "
                 "'debian-tag' option, default is '%(packaging-tag)s'",
+            'spec-file':
+                "Spec file to use, causes the packaging-dir option to be "
+                "ignored, default is '%(spec-file)s'",
                  })
 
 # vim:et:ts=4:sw=4:et:sts=4:ai:set list listchars=tab\:»·,trail\:·:
