@@ -16,6 +16,8 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """A Debian Changelog"""
 
+from __future__ import print_function
+
 import email
 import os
 import subprocess
@@ -166,21 +168,21 @@ class ChangeLog(object):
         @return: C{True} if the version has an epoch, C{False} otherwise
         @rtype: C{bool}
         """
-        return self._cp.has_key('Epoch')
+        return 'Epoch' in self._cp
 
     @property
     def author(self):
         """
         The author of the last modification
         """
-        return email.Utils.parseaddr(self._cp['Maintainer'])[0]
+        return email.utils.parseaddr(self._cp['Maintainer'])[0]
 
     @property
     def email(self):
         """
         The author's email
         """
-        return email.Utils.parseaddr(self._cp['Maintainer'])[1]
+        return email.utils.parseaddr(self._cp['Maintainer'])[1]
 
     @property
     def date(self):
@@ -245,8 +247,10 @@ class ChangeLog(object):
             args.extend(["--release", "--no-force-save-on-release"])
             msg = None
 
-        if author and email:
-            env = {'DEBFULLNAME': author, 'DEBEMAIL': email}
+        if author:
+            env['DEBFULLNAME'] = author
+        if email:
+            env['DEBEMAIL'] = email
 
         if distribution:
             args.append("--distribution=%s" % distribution)
@@ -264,11 +268,11 @@ class ChangeLog(object):
             new_cl = open("debian/changelog.bak", "w")
             for line in old_cl:
                 if line == "  * [[[insert-git-dch-commit-message-here]]]\n":
-                    print >> new_cl, "  * " + msg[0]
+                    print("  * " + msg[0], file=new_cl)
                     for line in msg[1:]:
-                        print >> new_cl, "    " + line
+                        print("    " + line, file=new_cl)
                 else:
-                    print >> new_cl, line,
+                    print(line, end='', file=new_cl)
             os.rename("debian/changelog.bak", "debian/changelog")
 
     def add_entry(self, msg, author=None, email=None, dch_options=[]):
