@@ -19,7 +19,7 @@
 import re
 from gbp.git import GitRepository, GitRepositoryError
 from gbp.deb.pristinetar import DebianPristineTar
-from gbp.format import format_msg
+from gbp.format import format_str
 
 class DebianGitRepository(GitRepository):
     """A git repository that holds the source of a Debian package"""
@@ -63,7 +63,8 @@ class DebianGitRepository(GitRepository):
                     return None
         return None
 
-    def debian_version_from_upstream(self, upstream_tag_format, commit='HEAD',
+    def debian_version_from_upstream(self, upstream_tag_format,
+                                     upstream_branch, commit='HEAD',
                                      epoch=None):
         """
         Build the Debian version that a package based on upstream commit
@@ -71,13 +72,15 @@ class DebianGitRepository(GitRepository):
 
         @param upstream_tag_format: the tag format on the upstream branch
         @type upstream_tag_format: C{str}
+        @param upstream_branch: the upstream branch
+        @type upstream_branch: C{str}
         @param commit: the commit to search for the latest upstream version
         @param epoch: an epoch to use
         @returns: a new debian version
         @raises GitRepositoryError: if no upstream tag was found
         """
         pattern = upstream_tag_format % dict(version='*')
-        tag = self.find_tag(commit, pattern=pattern)
+        tag = self.find_branch_tag(commit, upstream_branch, pattern=pattern)
         version = self.tag_to_version(tag, upstream_tag_format)
 
         version += "-1"
@@ -102,10 +105,20 @@ class DebianGitRepository(GitRepository):
     def version_to_tag(format, version):
         """Generate a tag from a given format and a version
 
+        %(version)s provides a clean version that works as a git tag.
+
+        %(hversion)s provides the same thing, but with '.' replaced with '-'.
+        hversion is useful for upstreams with tagging policies that prohibit .
+        characters.
+
         >>> DebianGitRepository.version_to_tag("debian/%(version)s", "0:0~0")
         'debian/0%0_0'
+        >>> DebianGitRepository.version_to_tag("libfoo-%(hversion)s", "1.8.1")
+        'libfoo-1-8-1'
+
         """
-        return format_msg(format, dict(version=DebianGitRepository._sanitize_version(version)))
+        return format_str(format, dict(version=DebianGitRepository._sanitize_version(version),
+                                       hversion=DebianGitRepository._sanitize_version(version).replace('.','-')))
 
     @staticmethod
     def _sanitize_version(version):
