@@ -20,6 +20,8 @@ import os
 from gbp.deb.format import DebianSourceFormat
 from gbp.deb.changelog import ChangeLog
 
+import six
+
 class FileVfs(object):
     def __init__(self, dir):
         """
@@ -51,14 +53,14 @@ class DebianSource(object):
         """
         self._changelog = None
 
-        if isinstance(vfs, basestring):
+        if isinstance(vfs, six.string_types):
             self._vfs = FileVfs(vfs)
         else:
             self._vfs = vfs
 
     def is_native(self):
         """
-        Whether this is a native debian package
+        Whether this is a native Debian package
         """
         try:
             ff = self._vfs.open('debian/source/format')
