@@ -71,8 +71,23 @@ def pq_branch_base(pq_branch):
         return pq_branch[len(PQ_BRANCH_PREFIX):]
 
 
-def parse_gbp_commands(info, cmd_tag, noarg_cmds, arg_cmds):
-    """Parse gbp commands from commit message"""
+def parse_gbp_commands(info, cmd_tag, noarg_cmds, arg_cmds, filter_cmds=None):
+    """
+    Parses gbp commands from commit message. Args with and wthout
+    arguments are supported as is filtering out of commands from the
+    commit body.
+
+    @param info: the commit into to parse for commands
+    @param cmd_tag: the command tag
+    @param noarg_cmds: commands without an argument
+    @type  noarg_cmds: C{list} of C{str}
+    @param arg_cmds: command with an argumnt
+    @type  arg_cmds: C{list} of C{str}
+    @param filter_cmds: commands to filter out of the passed in info
+    @type  filter_cmds: C{list} of C{str}
+    @returns: the parsed commands and the filtered commit body.
+    """
+    body = []
     cmd_re = re.compile(r'^%s:\s*(?P<cmd>[a-z-]+)(\s+(?P<args>\S.*))?' %
                             cmd_tag, flags=re.I)
     commands = {}
@@ -91,7 +106,14 @@ def parse_gbp_commands(info, cmd_tag, noarg_cmds, arg_cmds):
             else:
                 gbp.log.warn("Ignoring unknown gbp-command '%s' in commit %s"
                                 % (line, info['id']))
-    return commands
+            if filter_cmds is None or cmd not in filter_cmds:
+                body.append(line)
+        else:
+            body.append(line)
+    msg = '\n'.join(body)
+    # Add trailing newline if the originial body hat one
+    #msg += '\n' if info['body'] and info['body'][-1] == '\n' else ''
+    return (commands, msg)
 
 
 def patch_path_filter(file_status, exclude_regex=None):
@@ -155,21 +177,8 @@ def write_patch_file(filename, commit_info, diff):
 
 
 def format_patch(outdir, repo, commit_info, series, numbered=True,
-                 topic_regex=None, path_exclude_regex=None, topic=''):
+                 path_exclude_regex=None, topic=''):
     """Create patch of a single commit"""
-    commit = commit_info['id']
-
-    # Parse and filter commit message body
-    mangled_body = ""
-    for line in commit_info['body'].splitlines():
-        if topic_regex:
-            match = re.match(topic_regex, line, flags=re.I)
-            if match:
-                topic = match.group('topic')
-                gbp.log.debug("Topic %s found for %s" % (topic, commit))
-                continue
-        mangled_body += line + '\n'
-    commit_info['body'] = mangled_body
 
     # Determine filename and path
     outdir = os.path.join(outdir, topic)
@@ -194,8 +203,8 @@ def format_patch(outdir, repo, commit_info, series, numbered=True,
     # Finally, create the patch
     patch = None
     if paths:
-        diff = repo.diff('%s^!' % commit, paths=paths, stat=80, summary=True,
-                         text=True)
+        diff = repo.diff('%s^!' % commit_info['id'], paths=paths, stat=80,
+                         summary=True, text=True)
         patch = write_patch_file(filepath, commit_info, diff)
         if patch:
             series.append(patch)
@@ -265,6 +274,7 @@ def switch_to_pq_branch(repo, branch):
 def apply_single_patch(repo, branch, patch, fallback_author, topic=None):
     switch_to_pq_branch(repo, branch)
     apply_and_commit_patch(repo, patch, fallback_author, topic)
+    gbp.log.info("Applied %s" % os.path.basename(patch.path))
 
 
 def apply_and_commit_patch(repo, patch, fallback_author, topic=None):
@@ -287,7 +297,7 @@ def apply_and_commit_patch(repo, patch, fallback_author, topic=None):
     tree = repo.write_tree()
     msg = "%s\n\n%s" % (patch.subject, patch.long_desc)
     if topic:
-        msg += "\nGbp-Pq-Topic: %s" % topic
+        msg += "\nGbp-Pq: Topic %s" % topic
     commit = repo.commit_tree(tree, msg, [repo.head], author=author)
     repo.update_ref('HEAD', commit, msg="gbp-pq import %s" % patch.path)
 
@@ -304,3 +314,13 @@ def drop_pq(repo, branch):
         gbp.log.info("Dropped branch '%s'." % pq_branch)
     else:
         gbp.log.info("No patch queue branch found - doing nothing.")
+
+
+def switch_pq(repo, current):
+    """Switch to patch-queue branch if on base branch and vice versa"""
+    if is_pq_branch(current):
+        base = pq_branch_base(current)
+        gbp.log.info("Switching to %s" % base)
+        repo.checkout(base)
+    else:
+        switch_to_pq_branch(repo, current)
