@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2010,2012 Guido Günther <agx@sigxcpu.org>
+# (C) 2010, 2012, 2015 Guido Günther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -16,15 +16,20 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # Based on the aa-create-git-repo and dom-new-git-repo shell scripts
-"""Create a remote GIT repository based on the current one"""
+"""Create a remote Git repository based on the current one"""
 
-import ConfigParser
+from __future__ import print_function
+
+from six.moves import configparser
 import sys
 import os, os.path
-import urlparse
+from six.moves import urllib
 import subprocess
 import tty, termios
 import re
+
+import six
+
 from gbp.deb.changelog import ChangeLog, NoChangeLogError
 from gbp.command_wrappers import (CommandExecFailed, GitCommand)
 from gbp.config import (GbpOptionParserDebian, GbpOptionGroup)
@@ -51,22 +56,22 @@ def print_config(remote, branches):
             merge = refs/heads/bar
     """
 
-    print """[remote "%(name)s"]
+    print("""[remote "%(name)s"]
         url = %(url)s
-        fetch = +refs/heads/*:refs/remotes/%(name)s/*""" % remote
+        fetch = +refs/heads/*:refs/remotes/%(name)s/*""" % remote)
 
     for branch in branches:
-        print "        push = %s" % branch
+        print("        push = %s" % branch)
 
     for branch in branches:
-        print """[branch "%s"]
+        print("""[branch "%s"]
         remote = %s
-        merge = refs/heads/%s""" % (branch, remote['name'], branch)
+        merge = refs/heads/%s""" % (branch, remote['name'], branch))
 
 def sort_dict(d):
     """Return a sorted list of (key, value) tuples"""
     s = []
-    for key in sorted(d.iterkeys()):
+    for key in sorted(six.iterkeys(d)):
         s.append((key, d[key]))
     return s
 
@@ -103,7 +108,7 @@ def parse_url(remote_url, name, pkg, template_dir=None):
         ...
     GbpError: URL contains invalid ~username expansion.
     """
-    frags = urlparse.urlparse(remote_url)
+    frags = urllib.parse.urlparse(remote_url)
     if frags.scheme in ['ssh', 'git+ssh', '']:
         scheme = frags.scheme
     else:
@@ -232,7 +237,7 @@ def build_parser(name, sections=[]):
                                        usage='%prog [options] - '
                                        'create a remote repository',
                                        sections=sections)
-    except ConfigParser.ParsingError as err:
+    except configparser.ParsingError as err:
         gbp.log.err(err)
         return None
 
@@ -306,7 +311,7 @@ def main(argv):
     try:
         options, args = parse_args(argv)
     except Exception as e:
-        print >>sys.stderr, "%s" % e
+        print("%s" % e, file=sys.stderr)
         return 1
 
     gbp.log.setup(options.color, options.verbose, options.color_scheme)
@@ -350,11 +355,11 @@ def main(argv):
 
         remote_script = build_remote_script(remote, branches[0])
         if options.verbose:
-            print remote_script
+            print(remote_script)
 
         cmd = build_cmd(remote)
         if options.verbose:
-            print cmd
+            print(cmd)
 
         proc = subprocess.Popen(cmd, stdin=subprocess.PIPE)
         proc.communicate(remote_script)
@@ -372,7 +377,7 @@ def main(argv):
     except CommandExecFailed:
         retval = 1
     except (GbpError, GitRepositoryError) as err:
-        if len(err.__str__()):
+        if str(err):
             gbp.log.err(err)
         retval = 1
 
